@@ -50,15 +50,6 @@ arg_enum! {
 #[structopt(author = AUTHORS, about = ABOUT)]
 #[serde(default, deny_unknown_fields)]
 pub struct Opt {
-    #[structopt(
-        short = "p",
-        long = "palette",
-        possible_values = & PaletteType::variants(),
-        case_insensitive = true,
-        help = "Displays color palette",
-    )]
-    pub palette: Option<PaletteType>,
-
     #[structopt(
         short = "v",
         long = "version",
@@ -68,9 +59,6 @@ pub struct Opt {
     #[serde(skip_serializing, skip_deserializing)]
     pub version: bool,
 
-    #[structopt(long = "no-ascii", short = "n", help = "Removes the ascii art")]
-    pub no_ascii: bool,
-
     #[structopt(
     short = "o",
     long = "show",
@@ -109,22 +97,6 @@ pub struct Opt {
     )]
     pub theme: Option<String>,
 
-    #[structopt(
-        long = "custom-ascii",
-        short = "C",
-        help = "Specify your own ASCII art from a text file (supports ANSI escape codes)",
-        conflicts_with = "no_ascii"
-    )]
-    pub custom_ascii: Option<String>,
-
-    #[structopt(
-        long = "small-ascii",
-        short = "a",
-        help = "Prefer smaller ASCII variants",
-        conflicts_with = "no_ascii"
-    )]
-    pub small_ascii: bool,
-
     #[structopt(
         long = "export-config",
         short = "e",
@@ -177,14 +149,10 @@ impl Default for Opt {
             long_uptime: false,
             long_kernel: true,
             list_themes: false,
-            no_ascii: false,
-            small_ascii: false,
             ascii_artists: false,
-            custom_ascii: None,
             config: None,
             theme: None,
             show: None,
-            palette: None,
             interface: None,
         }
     }
